<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'svenska [sv]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'spip-dev@rezo.net',

// A
'access_interface_graphique' => 'Tillbaka till det kompletta grafiska gr&auml;nssnittet',
'access_mode_texte' => 'Visa det f&ouml;renklade text-gr&auml;nssnittet',
'admin_debug' => 'avlusa',
'admin_modifier_article' => '&Auml;ndra artikeln',
'admin_modifier_auteur' => '&Auml;ndra f&ouml;rfattaren',
'admin_modifier_breve' => '&Auml;ndra nyheten',
'admin_modifier_mot' => '&Auml;ndra nyckelordet',
'admin_modifier_rubrique' => '&Auml;ndra avdelningen',
'admin_recalculer' => 'Ladda om sidan',
'afficher_trad' => 'Visa &ouml;vers&auml;ttning',
'alerte_maj_impossible' => '<b>Varning!</b> Misslyckades med att uppdatera SQL-databasen till version @version@. Det kan bero p&aring; ett &aring;tkomstproblem med databasen. Var v&auml;nlig ta kontakt med din ISP.',
'alerte_modif_info_concourante' => 'VARNING: Denna information har &auml;ndrats p&aring; annan plats. Det aktuella inneh&aring;llet &auml;r:',
'analyse_xml' => 'Unders&ouml;k XML',
'annuler' => 'Avbryt',
'antispam_champ_vide' => 'Var v&auml;nlig, l&auml;mna f&auml;ltet tomt',
'articles_recents' => 'De senaste artiklarna',
'avis_archive_incorrect' => 'Arkivfilen &auml;r inte en godk&auml;nd SPIP-fil',
'avis_archive_invalide' => 'Arkivfilen &auml;r inte godk&auml;nd',
'avis_attention' => 'SE UPP!',
'avis_champ_incorrect_type_objet' => 'Ogiltigt f&auml;lt-namn f&ouml;r objekt av typen @type@',
'avis_colonne_inexistante' => 'Kolumnen @col@ finns inte',
'avis_echec_syndication_01' => 'Uppkopplingen misslyckades: K&auml;llfilen &auml;r antingen otydbar eller s&aring; inneh&aring;ller den ingen artikel. ',
'avis_echec_syndication_02' => 'Uppkopplingen misslyckades: Det var inte m&ouml;jligt att komma &aring;t syndikeringsfilen.',
'avis_erreur' => 'Fel: se nedan\\\';',
'avis_erreur_connexion' => 'Anslutningsfel',
'avis_erreur_cookie' => 'cookieproblem',
'avis_erreur_fonction_contexte' => 'Programmeringsfel. Den h&auml;r funktionen borde inte bli kallad i det h&auml;r sammanhanget.',
'avis_erreur_mysql' => 'SQL-fel',
'avis_erreur_sauvegarde' => 'Fel p&aring; s&auml;kerhetskopian (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Det har uppst&aring;tt ett problem med att g&aring; in i den privata delen',

// B
'barre_a_accent_grave' => 'Skapa ett stort A med bak&aring;tv&auml;nd accent',
'barre_aide' => 'Anv&auml;nd de typografiska genv&auml;garna f&ouml;r att f&ouml;rb&auml;ttra din layout',
'barre_e_accent_aigu' => 'Skapa ett stort E med fram&aring;tv&auml;nd accent',
'barre_eo' => 'Skapa en gemen oe-ligatur',
'barre_eo_maj' => 'Skapa en versal EO-ligature',
'barre_euro' => 'Skapa &amp;euro; symbolen',
'barre_gras' => 'S&auml;tt i {{fet}} stil',
'barre_guillemets' => 'Placera mellan "dubbla citationstecken"',
'barre_guillemets_simples' => 'Placera mellan ‘enkla citationstecken’',
'barre_intertitre' => 'G&ouml;r till en {{{underrubrik}}}',
'barre_italic' => 'S&auml;tt i {kursiv} stil',
'barre_lien' => 'G&ouml;r till en [l&auml;nk->http://...]',
'barre_lien_input' => 'Var god och ange m&aring;let f&ouml;r din l&auml;nk (du kan ange en internet-adress s&aring; som http://www.example.com eller helt enkelt numret p&aring; en artikel p&aring; den h&auml;r sajten).',
'barre_note' => 'G&ouml;r till en [[Fotnot]]',
'barre_paragraphe' => 'skapa ett stycke',
'barre_quote' => '<quote>Citera ett meddelande</quote>',
'bouton_ajouter_document' => 'L&auml;gg till ett dokument',
'bouton_ajouter_image' => 'L&auml;gg till en bild',
'bouton_ajouter_image_document' => 'L&auml;gg till en bild eller ett dokument',
'bouton_changer' => '&Auml;ndra',
'bouton_chercher' => 'S&ouml;k',
'bouton_choisir' => 'V&auml;lj',
'bouton_download' => 'Ladda hem',
'bouton_enregistrer' => 'Spara',
'bouton_radio_desactiver_messagerie_interne' => 'St&auml;ng av m&ouml;jligheten med interna meddelanden',
'bouton_radio_envoi_annonces' => 'Skicka redaktionella tillk&auml;nnagivanden',
'bouton_radio_non_envoi_annonces' => 'Skicka inga tillk&auml;nnagivanden',
'bouton_radio_non_envoi_liste_nouveautes' => 'Skicka inte en lista med senaste nyheter',
'bouton_recharger_page' => 'ladda om sidan',
'bouton_telecharger' => 'Ladda upp',
'bouton_valider' => 'Spara',

// C
'cal_apresmidi' => 'eftermiddag (e.m)',
'cal_jour_entier' => 'hel dag',
'cal_matin' => 'f&ouml;rmiddag (f.m)',
'cal_par_jour' => 'daglig kalendar',
'cal_par_mois' => 'm&aring;nadsvis kalender',
'cal_par_semaine' => 'veckovis kalender',
'choix_couleur_interface' => 'F&auml;rg',
'choix_interface' => 'val av gr&auml;nssnitt',
'colonne' => 'Kolumn',
'confirm_changer_statut' => 'Krav p&aring; bekr&auml;ftelse: Du har bett om att &auml;ndra statusen p&aring; den h&auml;r artikeln. Vill du forts&auml;tta?',
'correcte' => 'r&auml;tt',

// D
'date_aujourdhui' => 'idag',
'date_avant_jc' => 'f.Kr.',
'date_dans' => 'om @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'imorgon',
'date_fmt_heures_minutes' => '@h@:@m@',
'date_fmt_jour_heure' => '@jour@ klockan @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jour@-@nommois@-@annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'p&aring; @nomjour@, @date@',
'date_heures' => 'timmar',
'date_hier' => 'ig&aring;r',
'date_il_y_a' => '@delai@ sen',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 's&ouml;ndag',
'date_jour_1_abbr' => 's&ouml;',
'date_jour_1_initiale' => 's',
'date_jour_2' => 'm&aring;ndag',
'date_jour_2_abbr' => 'm&aring;',
'date_jour_2_initiale' => 'm',
'date_jour_3' => 'tisdag',
'date_jour_3_abbr' => 'ti',
'date_jour_3_initiale' => 't',
'date_jour_4' => 'onsdag',
'date_jour_4_abbr' => 'on',
'date_jour_4_initiale' => 'o',
'date_jour_5' => 'torsdag',
'date_jour_5_abbr' => 'to',
'date_jour_5_initiale' => 't',
'date_jour_6' => 'fredag',
'date_jour_6_abbr' => 'fr',
'date_jour_6_initiale' => 'f',
'date_jour_7' => 'l&ouml;rdag',
'date_jour_7_abbr' => 'l&ouml;',
'date_jour_7_initiale' => 's',
'date_jours' => 'dagar',
'date_minutes' => 'minuter',
'date_mois' => 'm&aring;nader',
'date_mois_1' => 'Januari',
'date_mois_10' => 'Oktober',
'date_mois_11' => 'November',
'date_mois_12' => 'December',
'date_mois_2' => 'Februari',
'date_mois_3' => 'Mars',
'date_mois_4' => 'April',
'date_mois_5' => 'Maj',
'date_mois_6' => 'Juni',
'date_mois_7' => 'Juli',
'date_mois_8' => 'Augusti',
'date_mois_9' => 'September',
'date_saison_1' => 'vinter',
'date_saison_2' => 'v&aring;r',
'date_saison_3' => 'sommar',
'date_saison_4' => 'h&ouml;st',
'date_secondes' => 'sekunder',
'date_semaines' => 'veckor',
'date_un_mois' => 'm&aring;nad',
'date_une_heure' => 'timme',
'date_une_minute' => 'minut',
'date_une_seconde' => 'sekund',
'date_une_semaine' => 'vecka',
'dirs_commencer' => ' f&ouml;r att verkligen kunna p&aring;b&ouml;rja installationen',
'dirs_preliminaire' => 'Prelimin&amp;auml;rt: <b>St&amp;auml;ller in r&amp;auml;ttigheterna</b>',
'dirs_probleme_droits' => 'Problem med &aring;tkomst-r&auml;ttigheter',
'dirs_repertoires_absents' => '<b>F&ouml;ljande kataloger har inte hittats: <ul>@bad_dirs@.</ul> </b><p>Det beror antagligen p&aring; d&aring;ligt anv&auml;ndande av gemena och VERSALER i namngivandet. Var god kontrollera att de gemena och VERSALA bokst&auml;verna i namnet p&aring; katalogerna motsvarar det som visas ovan; om s&aring; inte &auml;r fallet, &auml;ndra namnen med hj&auml;lp av dini FTP-klient f&ouml;r att &aring;tg&auml;rda felet.</p><p>N&auml;r det &auml;r gjort, kan du ',
'dirs_repertoires_suivants' => '<b>F&ouml;ljande kataloger saknar skriv-r&auml;ttigheter: <ul>@bad_dirs@.</ul> </b><p>F&ouml;r att &auml;ndra det, anv&auml;nd din FTP-klient f&ouml;r att s&auml;tta korrekta &aring;tkomstr&auml;ttigheter f&ouml;r katalogerna. Proceduren beskrivs i installationsguiden.</p><p>N&auml;r det &auml;r avklarat, kan du ',
'double_occurrence' => 'Tv&aring; exempel p&aring; @balise@',

// E
'en_cours' => 'arbetar',
'entree_dimensions' => 'Storlek:',
'entree_titre_document' => 'Titel p&aring; dokumentet:',
'entree_titre_image' => 'Titel p&aring; bilden:',
'envoi_via_le_site' => 'Skicka genom sajten',
'erreur' => 'Fel',
'erreur_balise_non_fermee' => 'Den sista tagen &auml;r inte st&auml;ngd:',
'erreur_texte' => 'fel',
'etape' => 'Etapp',

// F
'fichier_introuvable' => 'Fil som inte kunde hittas: @fichier@',
'form_auteur_confirmation' => 'Bekr&auml;fta din e-postadress',
'form_auteur_email_modifie' => 'Din e-postadress &auml;r nu &auml;ndrad.',
'form_auteur_envoi_mail_confirmation' => 'En bekr&auml;ftelse har skickats med e-post till @email@. Klicka p&aring; den l&auml;nk som du hittar i detta meddelande f&ouml;r att bekr&auml;fta din e-postadress.',
'form_auteur_mail_confirmation' => 'Hej,

du vill &auml;ndra din e-postadress.
F&ouml;r att bekr&auml;fta din nya adress m&aring;ste du g&aring; till
 adressen nedan. (Annars kommer adress&auml;ndringen inte att genomf&ouml;ras.):

    @url@
',
'form_deja_inscrit' => 'Du &auml;r redan registrerad',
'form_email_non_valide' => 'Din epost-adress &auml;r ogiltig',
'form_forum_access_refuse' => 'Du har inte l&auml;ngre tillg&aring;ng till den h&auml;r sajten',
'form_forum_bonjour' => 'Hej @nom@,',
'form_forum_email_deja_enregistre' => 'Epost-adressen &auml;r redan i bruk, du kan allts&aring; anv&auml;nda ditt vanliga l&ouml;senord',
'form_forum_identifiant_mail' => 'Dina nya anv&auml;ndaruppgifter har precis skickats till dig med epost.',
'form_forum_identifiants' => 'Personliga anv&auml;ndaruppgifter',
'form_forum_indiquer_nom_email' => 'Skriv in ditt namn och din epost-adress h&auml;r s&aring; kommer du att f&aring; dina personliga anv&auml;ndaruppgifter med epost inom kort.',
'form_forum_login' => 'logga in:',
'form_forum_message_auto' => '(detta &auml;r ett automatiskt meddelande)',
'form_forum_pass' => 'l&ouml;senord:',
'form_forum_probleme_mail' => 'Epost problem: anv&auml;ndaruppgifterna kunde inte skickas.',
'form_forum_voici1' => 'H&auml;r &auml;r dina anv&auml;ndaruppgifter f&ouml;r att kunna kan delta i sajtens liv
"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'H&auml;r &auml;r dina anv&auml;ndaruppgifter f&ouml;r att skriva artiklar
 f&ouml;r sajten "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Var god ange in din epost-adress.',
'form_indiquer_nom' => 'Var god ange in ditt namn.',
'form_indiquer_nom_site' => 'Var god och ange din sajts namn',
'form_pet_adresse_site' => 'Din sajts URL',
'form_pet_aucune_signature' => 'Inga underskrifter motsvarar denna kod...',
'form_pet_confirmation' => 'Var god och bekr&auml;fta din underskrift:',
'form_pet_deja_enregistre' => 'Den h&auml;r sajten &auml;r redan registrerad',
'form_pet_deja_signe' => 'Du har redan skrivit under texten.',
'form_pet_envoi_mail_confirmation' => 'Ett epost med en beg&auml;ran om bekr&auml;ftelse har precis skickats till @email@. Du b&ouml;r bes&ouml;ka den URL som st&aring;r i brevet f&ouml;r att bekr&auml;fta din inmatning.',
'form_pet_mail_confirmation' => 'Hej,

Du har beg&auml;rt att skriva under namninsamlingen:
@titre@.

Du angav f&ouml;ljande information:
    Namn: @nom_email@
    Sajt: @nom_site@ - @url_site@

VIKTIGT...
F&ouml;r att bekr&auml;fta din underskrift beh&ouml;ver du bes&ouml;ka
adressen nedan (annars kommer din beg&auml;ran att nekas:
    @url@

Tack f&ouml;r ditt deltagande
',
'form_pet_message_commentaire' => 'N&aring;got meddelande eller kommentar?',
'form_pet_nom_site2' => 'Namn p&aring; din webbssajt',
'form_pet_probleme_liens' => 'Var v&auml;nlig &auml;ndra ditt meddelande, ta bort alla hyperl&auml;nkar.',
'form_pet_probleme_technique' => 'Registrering &auml;r tillf&auml;lligtvis om&ouml;jligt p&aring; grund av ett tekniskt problem.',
'form_pet_signature_pasprise' => 'Din underskrift har ignorerats.',
'form_pet_signature_validee' => 'Din signatur &auml;r giltig. Tack!',
'form_pet_site_deja_enregistre' => 'Den h&auml;r sajten &auml;r redan registrerad',
'form_pet_url_invalide' => 'URL:en som du angivit &auml;r inte giltig.',
'form_pet_votre_email' => 'Din epost-adress',
'form_pet_votre_nom' => 'Ditt namn eller aliass',
'form_pet_votre_site' => 'Om du har en webbssajt, kan du ange dess adress nedan',
'form_prop_confirmer_envoi' => 'Bekr&auml;fta',
'form_prop_description' => 'Beskrivning/kommentar',
'form_prop_enregistre' => 'Ditt f&ouml;rslag har sparats, det kommer att visas online n&auml;r det har godk&auml;nts av en administrat&ouml;r f&ouml;r denna sajt.',
'form_prop_envoyer' => 'Skicka ett meddelande',
'form_prop_indiquer_email' => 'Var god och ange en giltig epost-adress',
'form_prop_indiquer_nom_site' => 'Var god och ange sajtens namn',
'form_prop_indiquer_sujet' => 'Var god och ange ett &auml;mne',
'form_prop_message_envoye' => 'Meddelandet skickat',
'form_prop_nom_site' => 'Sajtens namn',
'form_prop_non_enregistre' => 'Ditt f&ouml;rslag har inte sparats.',
'form_prop_sujet' => '&Auml;mne',
'form_prop_url_site' => 'Sajtens URL',
'forum_acces_refuse' => 'Du har inte l&auml;ngre tillg&aring;ng till dessa forum.',
'forum_attention_dix_caracteres' => '<b>Varning!</b> Ditt meddelande m&aring;ste vara minst 10 tecken l&aring;ngt.',
'forum_attention_trois_caracteres' => '<b>Varning!</b> Din rubrik m&aring;ste vara minst tre tecken l&aring;ng.',
'forum_attention_trop_caracteres' => '<b>Warning&nbsp;!</b> Ditt meddelande &auml;r f&ouml;r l&aring;ngt (@compte@ characters)&nbsp;: F&ouml;r att det skall kunna skrivas f&aring;r meddelandet inte inneh&aring;lla mer &auml;n @max@ tecken.',
'forum_avez_selectionne' => 'Du har valt:',
'forum_cliquer_retour' => 'Klicka <a href=\'@retour_forum@\'>h&auml;r</a> f&ouml;r att forts&auml;tta.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Detta forum &auml;r modererat: ditt bidrag kommer att synas f&ouml;rst n&auml;r n&aring;gon moderator har godk&auml;nt  det.',
'forum_lien_hyper' => '<b>L&auml;nk</b> (valfritt)',
'forum_message_definitif' => 'Slutligt meddelande: skicka till sajten',
'forum_message_trop_long' => 'Ditt meddelande &auml;r f&ouml;r l&aring;ngt. Det f&aring;r inte vara mer &auml;n 2000 tecken.',
'forum_ne_repondez_pas' => 'Svara inte p&aring; detta brev utan i forumet p&aring; denna adress:',
'forum_non_inscrit' => 'Antingen &auml;r du inte registrerad eller s&aring; &auml;r adressen eller l&ouml;senordet felaktigt.',
'forum_page_url' => '(Om ditt meddelande refererar till en artikel publicerad p&aring; webben eller till en sida med mer information, ange namnet p&aring; sidan och dess adress nedan).',
'forum_par_auteur' => 'av @auteur@',
'forum_poste_par' => 'Meddelande inskickat@parauteur@ efter din artikel',
'forum_probleme_database' => 'Databas-problem, ditt meddelande kunde inte sparas.',
'forum_qui_etes_vous' => '<b>Vem &auml;r du?</b> (valfritt)',
'forum_texte' => 'Texten i meddelandet:',
'forum_titre' => '&Auml;mne:',
'forum_titre_erreur' => 'Fel...',
'forum_url' => 'URL:',
'forum_valider' => 'Granska valet',
'forum_voir_avant' => 'F&ouml;rhandsgranska meddelandet innan du skickar det',
'forum_votre_email' => 'Din epost-adress',
'forum_votre_nom' => 'Ditt namn (eller alias):',
'forum_vous_enregistrer' => 'F&ouml;r att delta
 i detta forum m&aring;ste du vara registrerad. Var v&auml;nlig
  att skriv in ditt anv&auml;ndarnamn som du fick.
 Om du inte &auml;r registrerad, m&aring;ste du  ',
'forum_vous_inscrire' => 'registrera dig.',

// I
'ical_texte_rss_articles' => 'filen &laquo;backend&raquo; f&ouml;r artiklarna p&aring; den h&auml;r sajten finns p&aring; adressen:',
'ical_texte_rss_articles2' => 'Dessutom kan du h&auml;mta backendfiler f&ouml;r artiklarna i var och en av sajtens olika avdelningar:',
'ical_texte_rss_breves' => 'Dessutom finns det en fil somo inneh&aring;ller sajtenss nyheter. Genom att v&auml;lja ett avdelnings-nummer, kan du f&aring; enbart de nyheter som tillh&ouml;r den avdelningen.',
'icone_a_suivre' => 'Forts&auml;tt',
'icone_admin_site' => 'Administrera sajten',
'icone_agenda' => 'Kalender',
'icone_aide_ligne' => 'Hj&auml;lp',
'icone_articles' => 'Artiklar',
'icone_auteurs' => 'F&ouml;rfattare',
'icone_breves' => 'Nyheter',
'icone_brouteur' => 'Snabb-surfning',
'icone_configuration_site' => 'Konfiguration',
'icone_configurer_site' => 'Konfigurera din sajt',
'icone_creer_nouvel_auteur' => 'Skapa en ny f&ouml;rfattare',
'icone_creer_rubrique' => 'Skapa en avdelning',
'icone_creer_sous_rubrique' => 'Skapa en underavdelning',
'icone_deconnecter' => 'Logga ut',
'icone_discussions' => 'Diskutioner',
'icone_doc_rubrique' => 'Bifogade dokument',
'icone_ecrire_article' => 'Skriv en ny artikel',
'icone_edition_site' => 'Redigera sajten',
'icone_forum_administrateur' => 'Administrat&ouml;rernas forum',
'icone_forum_suivi' => 'Vidare till forumen',
'icone_gestion_langues' => 'Spr&aring;k-hantering',
'icone_informations_personnelles' => 'Personlig information',
'icone_interface_complet' => 'Fullst&auml;ndigt gr&auml;nssnitt',
'icone_interface_simple' => 'F&ouml;renklat gr&auml;nssnitt',
'icone_maintenance_site' => 'Underh&aring;ll av sajten',
'icone_messagerie_personnelle' => 'Personligt meddelandesystem',
'icone_mots_cles' => 'Nyckelord',
'icone_nouvelle_breve' => 'Skriv en ny nyhet',
'icone_repartition_actuelle' => 'Visa den nuvarande f&ouml;rdelningen',
'icone_repartition_debut' => 'Visa f&ouml;rdelningen fr&aring;n starten',
'icone_repartition_visites' => 'F&ouml;rdelning av bes&ouml;k',
'icone_rubriques' => 'Avdelningar',
'icone_sauver_site' => 'S&auml;kerhetskopiera sajten',
'icone_site_entier' => 'Hela sajten',
'icone_sites_references' => 'L&auml;nkade sajter',
'icone_statistiques' => 'Statistik f&ouml;r sajten',
'icone_statistiques_visites' => 'Statistik',
'icone_suivi_activite' => 'Uppf&ouml;ljning av sajtens aktivitet',
'icone_suivi_actualite' => 'Statistik f&ouml;r sajten',
'icone_suivi_forums' => 'Hantera forumen',
'icone_suivi_pettions' => 'Hantera namninsamlingarna',
'icone_suivi_revisions' => 'F&ouml;r&auml;ndringar i artiklar',
'icone_supprimer_document' => 'Radera dokumentet',
'icone_supprimer_image' => 'Radera bilden',
'icone_supprimer_message' => 'Radera meddelandet',
'icone_tous_articles' => 'Alla dina artiklar',
'icone_tous_auteur' => 'Alla f&ouml;rfattare',
'icone_valider_message' => 'Godk&auml;nn meddelandet',
'icone_visiter_site' => 'Bes&ouml;k sajten',
'icone_voir_en_ligne' => 'Se online',
'image_tourner_180' => 'Rotera 180&deg;',
'image_tourner_droite' => 'Rotera 90&deg; &aring;t h&ouml;ger',
'image_tourner_gauche' => 'Rotera 90&deg; &aring;t v&auml;nster',
'img_indisponible' => 'bilden &auml;r otillg&auml;nlig',
'impossible' => 'om&ouml;jlig(t)',
'info_a_suivre' => 'STARTPUNKT&raquo;',
'info_a_valider' => '[att godk&auml;nnas]',
'info_acces_interdit' => '&Aring;tkomst f&ouml;rbjuden',
'info_acces_refuse' => '&Aring;tkomst nekad',
'info_action' => '&Aring;tg&auml;rd: @action@',
'info_administrer_rubriques' => 'Du kan hantera avdelningen och dess under-avdelningar',
'info_adresse_non_indiquee' => 'Du angav inte en adress att prova!',
'info_aide' => 'HJ&Auml;LP:',
'info_ajouter_mot' => 'L&auml;gg till nyckelordet',
'info_annonce' => 'MEDDELANDE',
'info_annonces_generales' => 'Allm&auml;nna meddelanden:',
'info_article_propose' => 'Sparad artikel',
'info_article_publie' => 'Publicerad artikel',
'info_article_redaction' => 'Artikel under bearbetning',
'info_article_refuse' => 'Refuserad artikel',
'info_article_supprime' => 'Raderad artikel',
'info_articles' => 'Artiklar',
'info_articles_a_valider' => 'Artiklar som ska godk&auml;nnas',
'info_articles_nb' => '@nb@ artiklar',
'info_articles_proposes' => 'Sparade artiklar',
'info_articles_un' => '1 artikel',
'info_auteurs_nombre' => 'f&ouml;rfattare:',
'info_authentification_ftp' => 'Authentifiering (via FTP)',
'info_bloquer_lien' => 'blockera l&auml;nken',
'info_breves_02' => 'Nyheter',
'info_breves_2' => 'nyheter',
'info_breves_nb' => '@nb@ nyheter',
'info_breves_un' => '1 nyhet',
'info_breves_valider' => 'Nyheter som ska godk&auml;nnas',
'info_connexion_refusee' => 'Anslutning nekad',
'info_contact_developpeur' => 'Var god och ta kontakt med en utvecklare',
'info_contenance' => 'Sajten inneh&aring;ller:',
'info_contribution' => 'bidrag till forumen',
'info_copyright' => '@spip@ &auml;r fri programvara och distribueras @lien_gpl@.',
'info_copyright_doc' => 'F&ouml;r mer information, se (p&aring; engelska)<a href="@spipnet@">http://www.spip.net/en</a>.',
'info_copyright_gpl' => 'under GPL-licensen',
'info_cours_edition' => 'Dina artiklar under bearbetning',
'info_creer_repertoire' => 'Var god och skapa en katalog som heter:',
'info_creer_repertoire_2' => 'i under-katalogen <b>@repertoire@</b>, sedan',
'info_creer_vignette' => 'skapa en tumnagel automatiskt ',
'info_deplier' => '&Ouml;ppna',
'info_descriptif_nombre' => 'beskrivning(ar):',
'info_description' => 'Bekrivning:',
'info_description_2' => 'Beskrivning:',
'info_dimension' => 'Storlek:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'Dokumentet &auml;r inte tillg&auml;ngligt',
'info_documents' => 'Dokument',
'info_documents_nb' => '@nb@ dokument',
'info_documents_un' => '1 dokument',
'info_echange_message' => 'SPIP till&aring;ter utbyte av meddelanden och skapandet av privata
  diskussionsforum bland sajtens deltagare. Du kan till&aring;ta
  eller f&ouml;rbjuda det.',
'info_ecire_message_prive' => 'Skriv ett privat meddelande',
'info_email_invalide' => 'Ogiltigt epost-adress.',
'info_en_cours_validation' => 'Dina artiklar under arbete',
'info_en_ligne' => 'Online nu:',
'info_envoyer_message_prive' => 'Skicka ett privat meddelande till f&ouml;rfattaren',
'info_erreur_requete' => 'Fel i fr&aring;gan:',
'info_erreur_squelette2' => 'Det finns ingen mall <b>@fichier@</b>...',
'info_erreur_systeme' => 'Systemfel (errno @errsys@)',
'info_erreur_systeme2' => 'H&aring;rddisken kan vara full eller databasen kan vara skadad. <br />
 <font color=\'red\'>F&ouml;rs&ouml;k <a href=\'@script@\'>laga databasen</a>,
 eller kontakta din leverant&ouml;r.</font>',
'info_fini' => 'Klart!',
'info_format_image' => 'Bildformat som kan anv&auml;ndas f&ouml;r att skapa ikoner: @gd_formats@.',
'info_format_non_defini' => 'Odefinierat format',
'info_grand_ecran' => 'Stor bild',
'info_image_aide' => 'HJ&Auml;LP',
'info_image_process_titre' => 'Hur du skapar tumnaglar',
'info_impossible_lire_page' => '<b>Fel!</b> Sidan <tt><html>@test_proxy@</html></tt>  kan inte l&auml;sas genom proxyservern',
'info_inclusion_directe' => 'Direkt inkludering:',
'info_inclusion_vignette' => 'Inkludera miniatyr:',
'info_installation_systeme_publication' => 'Installation av publicerings-system ...',
'info_installer_documents' => 'Du kan automatiskt installera alla dokument som finns i katalogen @upload@.',
'info_installer_ftp' => 'Som administrat&ouml;r, kan du ladda upp filer (via FTP) till mappen @upload@ f&ouml;r att senare kunna v&auml;lja dem d&auml;rifr&aring;n.',
'info_installer_images' => 'Du kan anv&auml;nda bilder i formaten JPEG, GIF och PNG.',
'info_installer_images_dossier' => 'Ladda upp biilerna i katalogen @upload@ f&ouml;r att senare v&auml;lja dem d&auml;rifr&aring;n.',
'info_installer_tous_documents' => 'Insstallera alla dokument',
'info_interface_complete' => 'komplett gr&auml;nssnitt',
'info_interface_simple' => 'F&ouml;renklat gr&auml;nssnitt',
'info_joindre_document_article' => 'Till din artikel kan du bifoga filer i formaten',
'info_joindre_document_rubrique' => 'I avdelningen kan du l&auml;gga till dokument av typen',
'info_joindre_documents_article' => 'Till din artikel kan du bifoga filer i formaten:',
'info_l_article' => 'artikeln',
'info_la_breve' => 'nyheten',
'info_la_rubrique' => 'avdelningen',
'info_langue_principale' => 'Huvud-spr&aring;k f&ouml;r sajten',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixlar',
'info_les_auteurs_1' => 'av @les_auteurs@',
'info_logo_format_interdit' => 'Endast logotyper i formaten @formats@ &auml;r till&aring;tna.',
'info_logo_max_poids' => 'Logotypen m&aring;ste vara mindre &auml;n @maxi@ (Din fil &auml;r @actuel@).',
'info_logo_max_taille' => 'Logotypen m&aring;ste vara mindre &auml;n @maxi@ (din fil &auml;r @actuel@).',
'info_mail_fournisseur' => 'you@isp.com',
'info_message_2' => 'MEDDELANDE',
'info_message_supprime' => 'RADERAT MEDDELANDE',
'info_messages_nb' => '@nb@ meddelanden',
'info_messages_un' => '1 meddelande',
'info_mise_en_ligne' => 'Datum f&ouml;r publicering online',
'info_modification_parametres_securite' => 'uppdaterar s&auml;kerhetsinst&auml;llningar',
'info_mois_courant' => 'I m&aring;naden:',
'info_mot_cle_ajoute' => 'F&ouml;ljande nyckelord las till',
'info_multi_herit' => 'F&ouml;rvalt spr&aring;k',
'info_multi_langues_soulignees' => 'F&ouml;r de <u>understrukna spr&aring;ken</u> tillhandah&aring;ller SPIP en &ouml;vers&auml;ttning av all text i gr&auml;nssnittet. Om du v&auml;ljer dessa spr&aring;k, kommer m&aring;nga delar av den publika delen (datum, formul&auml;r) att &ouml;vers&auml;ttas automatiskt. F&ouml;r de spr&aring;k som inte &auml;r understrukna, kommer de delarna att vara i sajtens huvudspr&aring;k.',
'info_multilinguisme' => 'Flerspr&aring;kig',
'info_nom_non_utilisateurs_connectes' => 'Ditt namn visas inte i listan &ouml;ver anslutna anv&auml;ndare.',
'info_nom_utilisateurs_connectes' => 'Ditt namn visas i listan &ouml;ver anslutna anv&auml;ndare.',
'info_nombre_en_ligne' => 'Online nu:',
'info_non_resultat' => 'Inga ressultat f&ouml;r "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Du anv&auml;nder inte sajtens initerna meddelande-system',
'info_nouveau_message' => 'DU HAR ETT NYTT MEDDELANDE',
'info_nouveaux_messages' => 'DU HAR @total_messages@ NYA MEDDELANDEN',
'info_numero_abbreviation' => 'Nr',
'info_obligatoire' => 'Denna information &auml;r obligatorisk',
'info_panne_site_syndique' => 'Syndikerad sajt fungerar ej',
'info_pense_bete' => 'MEMO',
'info_petit_ecran' => 'Liten bild',
'info_petition_close' => 'Omr&ouml;stningen st&auml;ngd',
'info_pixels' => 'pixlar',
'info_plusieurs_mots_trouves' => 'Flear nyckelord hittades f&ouml;r "@cherche_mot@":',
'info_popularite_5' => 'popularitet:',
'info_portfolio' => 'Portf&ouml;lj',
'info_portfolio_automatique' => 'Automatiserad portf&ouml;lj',
'info_premier_resultat' => '[@debut_limit@ f&ouml;rsta resultaten av sammanlagt @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ f&ouml;rsta resultaten av sammanlagt @total@]',
'info_probleme_grave' => 'fel av',
'info_propose_1' => '[@nom_site_spip@] Skickad: @titre@',
'info_propose_2' => 'Skickad artikel
-----------------',
'info_propose_3' => 'Artikeln "@titre@" &auml;r skickad f&ouml;r publicering.',
'info_propose_4' => 'Du har blivit inbjuden att granska och kommentera den',
'info_propose_5' => 'i forumet kopplat till den. den &auml;r tillg&auml;nglig p&aring; adressen:',
'info_publie_01' => 'Artikeln "@titre@" godk&auml;ndes av @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICERADE: @titre@',
'info_publie_2' => 'Publicerad artikel
-----------------',
'info_rechercher' => 'S&ouml;k',
'info_rechercher_02' => 'S&ouml;k:',
'info_remplacer_vignette' => 'Byt ut standardikonen mot en egen ikon:',
'info_retablir_lien' => '&aring;terskapa den h&auml;r l&auml;nken',
'info_retirer_mot' => 'Radera nyckelordet',
'info_retirer_mots' => 'Radera alla nyckelord',
'info_rubriques_nb' => '@nb@ avdelningar',
'info_rubriques_un' => '1 avdelning',
'info_sans_titre_2' => 'utan titel',
'info_selectionner_fichier' => 'Du kan v&auml;lja en fil i foldern @upload@',
'info_selectionner_fichier_2' => 'V&auml;lj en fil:',
'info_signature_supprimee' => 'Underskriften raderades',
'info_signature_supprimee_erreur' => 'Fel: den h&auml;r raderingskoden motsvarar ingen underskrift',
'info_site_attente' => 'Webbsajten v&auml;ntar p&aring; godk&auml;nnande',
'info_site_reference' => 'L&auml;nkade sajter ',
'info_site_refuse' => 'Webbsajten refuserad',
'info_sites_nb' => '@nb@ sidor',
'info_sites_referencer' => 'L&auml;nka till en sajt',
'info_sites_un' => '1 sida',
'info_supprimer_vignette' => 'radera ikonen',
'info_symbole_bleu' => 'En <b>bl&aring;</b> symbol visar ett <b>meddelande</b>: ett personligt meddelande.',
'info_symbole_jaune' => 'En <b>gul</b> symbol visar ett <b>meddelande till alla redakt&ouml;rer</b>: det kan editeras av alla administrat&ouml;rer, och &auml;r synligt f&ouml;r alla redakt&ouml;rer.',
'info_symbole_vert' => 'En <b>gr&ouml;n</b> symbol visar <b>meddelanden fr&aring;n och till andra anv&auml;ndare</b> p&aring; sajten.',
'info_syndication' => 'syndikering:',
'info_syndication_articles' => 'artikel(ar)',
'info_telecharger' => 'Ladda upp fr&aring;n din dator:',
'info_telecharger_nouveau_logo' => 'Ladda upp en ny logotype:',
'info_telecharger_ordinateur' => 'Ladda upp fr&aring;n din dator:',
'info_tous_resultats_enregistres' => '[alla resultat &auml;r sparade]',
'info_tout_afficher' => 'Visa allt',
'info_travaux_texte' => 'Den h&auml;r websidan &auml;r inte f&auml;rdig. Kom g&auml;rna tilbaka senare...',
'info_travaux_titre' => 'Sajt i uppbyggnad',
'info_trop_resultat' => 'F&ouml;r m&aring;nga resultat f&ouml;r "@cherche_mot@"; f&ouml;rs&ouml;ka att avgr&auml;nsa s&ouml;kningen mer.',
'info_utilisation_messagerie_interne' => 'Du anv&auml;nder sajtens interna meddelandesystem.',
'info_valider_lien' => 'godk&auml;nn l&auml;nken',
'info_verifier_image' => ', kontrollera att bilderna &auml;r korrekt &ouml;verf&ouml;rda.',
'info_vignette_defaut' => 'Standardlogotype',
'info_vignette_personnalisee' => 'Anpassad logotyp',
'info_visite' => 'bes&ouml;k:',
'info_visites' => 'bes&ouml;k:',
'info_vos_rendez_vous' => 'Dina framtida m&ouml;ten',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Din meddelanden', # MODIF
'item_breve_proposee' => 'Inl&auml;mnad nyhet',

// L
'lien_afficher_icones_seuls' => 'Visa bara ikoner',
'lien_afficher_texte_icones' => 'Visa ikoner och text',
'lien_afficher_texte_seul' => 'Visa enbart text',
'lien_liberer' => 'version',
'lien_liberer_tous' => 'frig&ouml;r artiklarna',
'lien_nouvea_pense_bete' => 'Nytt memo',
'lien_nouveau_message' => 'NYTT MEDDELANDE',
'lien_nouvelle_annonce' => 'NYTT MEDDELANDE',
'lien_petitions' => 'NAMNINSAMLING',
'lien_popularite' => 'Popularitet: @popularite@%',
'lien_racine_site' => 'Sajtens bas',
'lien_reessayer' => 'F&ouml;rs&ouml;k igen',
'lien_repondre_message' => 'Svara p&aring; det h&auml;r meddelandet',
'lien_supprimer' => 'radera',
'lien_tout_afficher' => 'Visa alla',
'lien_visite_site' => 'Bes&ouml;k den h&auml;r sajten',
'lien_visites' => '@visites@ bes&ouml;kare',
'lien_voir_auteur' => 'Visa redakt&ouml;ren',
'ligne' => 'Rad',
'login' => 'F&ouml;rbindelse',
'login_acces_prive' => 'Tilltr&auml;de till den privata delen',
'login_autre_identifiant' => 'anv&auml;nd ett annat id ID',
'login_cookie_accepte' => 'Var v&auml;nlig, konfigurera din webbl&auml;sare s&aring; att den accepterar dem (&aring;tminstone f&ouml;r den h&auml;r sajten).',
'login_cookie_oblige' => 'F&ouml;r att identifiera dig s&auml;kert, m&aring;ste du acceptera cookies.',
'login_deconnexion_ok' => 'Du har loggat ut.',
'login_erreur_pass' => 'Felaktigt l&ouml;senord.',
'login_espace_prive' => 'privat del',
'login_identifiant_inconnu' => 'loginnamnet "@login@" &auml;r ok&auml;nt.',
'login_login' => 'Login:',
'login_login2' => 'Login (loginnamn f&ouml;r sajten):',
'login_login_pass_incorrect' => '(fel login eller l&ouml;senord).',
'login_motpasseoublie' => 'bortgl&ouml;mt l&ouml;senord?',
'login_non_securise' => 'Varning, detta formul&auml;r &auml;r inte s&auml;kert.
   Om du inte vill skicka ditt l&ouml;senord i klartext &ouml;ver internet
   Var v&auml;nlig och aktivera Javasvcript
  i din webbl&auml;sare och',
'login_nouvelle_tentative' => 'Nytt f&ouml;rs&ouml;k',
'login_par_ici' => 'Du &auml;r registrerad... den h&auml;r v&auml;gen...',
'login_pass2' => 'L&ouml;senord:',
'login_preferez_refuser' => '<b>Om du inte vill anv&auml;nda cookies</b>, s&aring; finns det en annan uppkopplingsmetod tillg&auml;nglig (mer os&auml;ker):',
'login_recharger' => 'ladda om sidan',
'login_rester_identifie' => 'Kom ih&aring;g mitt ID under n&aring;gra dagar',
'login_retour_public' => 'Tillbaka till den publika delen',
'login_retour_site' => 'Tillbaka till den publika delen',
'login_retoursitepublic' => 'Tillbaka till den publika delen',
'login_sans_cookiie' => 'Logga in utan cookie',
'login_securise' => 'S&auml;ker inloggning',
'login_sinscrire' => 'registrera dig',
'login_test_navigateur' => 'testar webbl&auml;sare/&aring;teruppkoppling',
'login_verifiez_navigateur' => '(Kontrollera att din webbl&auml;sare inte sparade l&ouml;senordet...)',

// M
'masquer_colonne' => 'G&ouml;m den h&auml;r kolumnen',
'masquer_trad' => 'g&ouml;m &ouml;vers&auml;ttningar',
'module_fichiers_langues' => 'Spr&aring;kfiler',

// N
'navigateur_pas_redirige' => 'Om din webbl&auml;sare inte pekas om, klicka h&auml;r f&ouml;r att forts&auml;tta.',
'numero' => 'Nummer',

// O
'occurence' => 'Instans',
'onglet_affacer_base' => 'Radera databasen',
'onglet_auteur' => 'Redakt&ouml;ren',
'onglet_contenu_site' => 'Sajtens inneh&aring;ll',
'onglet_evolution_visite_mod' => 'Bes&ouml;ksniv&aring;',
'onglet_fonctions_avances' => 'Avancerade inst&auml;llningar',
'onglet_informations_personnelles' => 'Personlig information',
'onglet_interactivite' => 'Interaktivitet',
'onglet_messagerie' => 'Meddelanden',
'onglet_messages_internes' => 'Interna meddelanden',
'onglet_messages_publics' => 'Publika meddelanden',
'onglet_messages_vide' => 'Meddelanden utan text',
'onglet_origine_visites' => 'Bes&ouml;karnas ursprung',
'onglet_repartition_debut' => 'fr&aring;n b&ouml;rjan',
'onglet_repartition_lang' => 'F&ouml;rdelning efter spr&aring;k',
'onglet_repartition_rubrique' => 'F&ouml;rdelning efter avdelning',
'onglet_save_restaur_base' => 'Backup/&aring;terst&auml;llande av databas',
'onglet_vider_cache' => 'T&ouml;m cachen',
'ortho_trop_de_fautes2' => 'B&ouml;rja genom att r&auml;tta de mest uppenbara misstagen och f&ouml;rs&ouml;k igen.',

// P
'pass_choix_pass' => 'Var v&auml;nlig, v&auml;lj ett nytt l&ouml;senord:',
'pass_erreur' => 'Fel',
'pass_erreur_acces_refuse' => '<b>Fel:</b> du har inte tilltr&auml;de till den h&auml;r sajten l&auml;ngre.',
'pass_erreur_code_inconnu' => '<b>Fel:</b> Den h&auml;r identiteten finns inte bland de som har tillg&aring;ng till den h&auml;r sajten.',
'pass_erreur_non_enregistre' => '<b>Fel :</b> adressen <tt>@email_oubli@</tt> &auml;r inte registrerad p&aring; den h&auml;r sajten.',
'pass_erreur_non_valide' => '<b>Fel :</b> mejladressen <tt>@email_oubli@</tt> &auml;r inte giltig!',
'pass_erreur_probleme_technique' => '<b>Fel :</b> mejlet kunde inte s&auml;ndas p&aring; grund av ett tekniskt problem.',
'pass_espace_prive_bla' => 'Den privata delen &auml;r &ouml;ppen f&ouml;r bes&ouml;kare
efter registrering. efter att du registrerat dig,
kan du se artiklarna under redigering,
l&auml;mna in artiklar och delta i alla forum.',
'pass_forum_bla' => 'Du har beg&auml;rt att f&aring; ta del av ett forum
som &auml;r reserverat f&ouml;r registrerade bes&ouml;kare.',
'pass_indiquez_cidessous' => 'Skriv in mejladressen som du anv&auml;nde 
vid registreringen h&auml;r under
Du kommer att f&aring; ett mejl som f&ouml;rklarar
hur du &aring;terigen kan f&aring; tillg&aring;ng.',
'pass_mail_passcookie' => '(det h&auml;r &auml;r ett automatiskt skapat meddelande)

F&ouml;r att &aring;terf&aring; tillg&aring;ng till sajten
@nom_site_spip@ (@adresse_site@)

var v&auml;nlig g&aring; till f&ouml;ljande webbadress:
    @sendcookie@

Du kan d&auml;r fylla i ett nytt l&ouml;senord
och koppla upp dig mot sajten igen.
',
'pass_mot_oublie' => 'Bortgl&ouml;mt l&ouml;senord',
'pass_nouveau_enregistre' => 'Ditt nya l&ouml;senord har sparats.',
'pass_nouveau_pass' => 'Nytt l&ouml;senord',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Gl&ouml;mma bort l&ouml;senord',
'pass_quitter_fenetre' => 'St&auml;ng detta f&ouml;nster',
'pass_rappel_login' => 'Kom ih&aring;g: ditt anv&auml;ndarnamn (login) &auml;r "@login@".',
'pass_recevoir_mail' => 'Du kommer att f&aring; ett mejl som f&ouml;rklarar hur du kan &aring;terf&aring; tillg&aring;ng till sajten.',
'pass_retour_public' => 'Tillbaka till den publika delen',
'pass_rien_a_faire_ici' => 'Det finns inget att g&ouml;ra h&auml;r.',
'pass_vousinscrire' => 'Registrera dig p&aring; sajten',
'precedent' => 'f&ouml;reg&aring;ende',
'previsualisation' => 'F&ouml;rhandsvisning',
'previsualiser' => 'visualisera',

// R
'retour' => 'G&aring; tillbaka',

// S
'spip_conforme_dtd' => 'SPIP anser att sidan st&auml;mmer med dess DOCTYPE:',
'squelette' => 'mall',
'squelette_inclus_ligne' => 'inkluderar mall, rad',
'squelette_ligne' => 'mall, rad',
'stats_visites_et_popularite' => '@visites@ bes&ouml;k; popularitet: @popularite@',
'suivant' => 'n&auml;sta',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => ' @taille@&nbsp;bytes',
'texte_actualite_site_1' => 'N&auml;r du vant dig vid gr&auml;nssnittet, klicka p&aring; &laquo;',
'texte_actualite_site_2' => 'Fullst&auml;ndigt gr&auml;nssnitt',
'texte_actualite_site_3' => '&raquo; f&ouml;r att g&ouml;ra fler funktioner tillg&auml;ngliga.',
'texte_creation_automatique_vignette' => 'Automatisk generering av miniatyrer &auml;r aktiverat p&aring; den h&auml;r sajten. Om du laddar upp bilder, i formaten @gd_formats@, med det h&auml;r formul&auml;ret, kommer de att kopplas till en miniatyr med maximal storlek @taille_preview@ pixlar.',
'texte_documents_associes' => 'F&ouml;ljande dokument &auml;r l&auml;nkade till artikeln,
    men de &auml;r inte direkt bifogade
    Beroende p&aring; sajtens utseende,
    kan de upptr&auml;da som bifogade dokument.',
'texte_erreur_mise_niveau_base' => 'Databasfel under uppgraderingen.
      Bilden <b>@fichier@</b> uppgraderades inte (artikel @id_article@).<p>
   Anteckna referensen och f&ouml;rs&ouml;k k&ouml;ra uppgraderingen igen,
   kontrollera efter&aring;t att bilderna fortfarande
      finns i artiklarna.',
'texte_erreur_visiteur' => 'Du har f&ouml;rs&ouml;kt att &ouml;ppna den privata delen med  en identitet som inte har tilltr&auml;de.',
'texte_inc_auth_1' => 'Du har identifierat dig med login
  <b>@auth_login@</b>, men det finns inte i databasen (l&auml;ngre). 
  F&ouml;rs&ouml;k att',
'texte_inc_auth_2' => 'Koppla upp igen',
'texte_inc_auth_3' => 'efter att ha st&auml;ngt och sedan
  omstartat webbl&auml;saren om n&ouml;dv&auml;ndigt.',
'texte_inc_config' => 'F&ouml;r&auml;ndringar som du g&ouml;r p&aring; denna sida p&aring;verkar starkt 
 sajtens funktion. Vi rekommenderar att du inte g&ouml;r n&aring;got innan du bekantat dig med funktionaliteten i SPIP. <br /><br /><b>I
 allm&auml;nhet, rekommenderas starkt
 att l&auml;mna ansvaret f&ouml;r dessa sidor  till sajtens huvudsakliga webbmaster. <b>',
'texte_inc_meta_1' => 'Ett fel intr&auml;ffade d&aring; systemet skrev <code>@fichier@</code>. Som administrat&ouml;r, var v&auml;nlig,',
'texte_inc_meta_2' => 'Kontrollera skrivr&auml;ttigheterna',
'texte_inc_meta_3' => 'i katalogen <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'under redaktion',
'texte_statut_poubelle' => 'i papperskorgen',
'texte_statut_propose_evaluation' => 'inl&auml;mnad f&ouml;r godk&auml;nnande',
'texte_statut_publie' => 'publicerad online',
'texte_statut_refuse' => 'refuserad',
'titre_ajouter_mot_cle' => 'L&Auml;GG TILL ETT NYCKELORD:',
'titre_breve_proposee' => 'Uppladdade nyheter',
'titre_breve_publiee' => 'Nyheten har publicerats',
'titre_breve_refusee' => 'Nyheten har refuserats',
'titre_cadre_raccourcis' => 'GENV&Auml;GAR:',
'titre_changer_couleur_interface' => 'Byter f&auml;rg p&aring; gr&auml;nssnittet',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Du kan redigera den h&auml;r artikeln',
'titre_image_administrateur' => 'Administrat&ouml;r',
'titre_image_aide' => 'Hj&auml;lp f&ouml;r den h&auml;r saken',
'titre_image_auteur_supprime' => 'Redakt&ouml;ren raderad',
'titre_image_redacteur' => 'Redakt&ouml;r utan beh&ouml;righet',
'titre_image_redacteur_02' => 'Redakt&ouml;r',
'titre_image_visiteur' => 'Bes&ouml;kare',
'titre_joindre_document' => 'BIFOGA ETT DOKUMENT',
'titre_liens_entrants' => 'Inkommande l&auml;nkar',
'titre_mots_cles' => 'NYCKELORD',
'titre_probleme_technique' => 'OBS!: ett tekniskt problem (databasservern) f&ouml;rhindrar tillg&aring;ng till den h&auml;r delen. Tack f&ouml;r f&ouml;rst&aring;elsen.',
'titre_publier_document' => 'PUBLICERA ETT DOKUMENT I DEN H&Auml;R AVDELNINGEN',
'titre_signatures_attente' => 'Bidrag i v&auml;ntan p&aring; validering',
'titre_signatures_confirmees' => 'Validerade bidrag',
'titre_statistiques' => 'Statistik f&ouml;r sajten',
'titre_titre_document' => 'Dokumentets titel:',
'todo' => 'Att g&ouml;ra',
'trad_reference' => '(refererad artikel)',

// Z
'zbug_balise_b_aval' => ': B taggen f&ouml;r sent i loopen',
'zbug_balise_inexistante' => 'fel @from@: taggen #@balise@ finns inte',
'zbug_balise_sans_argument' => 'Det saknas ett argument i taggen @balise@',
'zbug_boucle' => 'loop',
'zbug_boucle_recursive_undef' => 'recursiv slinga ej definierad', # MODIF
'zbug_calcul' => 'Omkompilering',
'zbug_champ_hors_boucle' => 'F&auml;lt @champ@ utanf&ouml;r slingan',
'zbug_champ_hors_motif' => 'F&auml;ltet @champ@ utanf&ouml;r slingan med taggen @motif@', # MODIF
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'Kriteriet @critere@ ok&auml;nt',
'zbug_distant_interdit' => 'externt data f&ouml;rbjudet', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'dubletter i en tabell utan prim&auml;r nyckel', # MODIF
'zbug_doublon_table_sans_index' => 'dubbletter i en tabell utan index', # MODIF
'zbug_erreur_boucle_double' => 'SLINGA@id@: Dubbel definition ', # MODIF
'zbug_erreur_boucle_fermant' => 'SLINGA@id@: Sista taggen saknas   ', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Felaktig syntax i slinga (BOUCLE) ', # MODIF
'zbug_erreur_compilation' => 'Kompileringsfel',
'zbug_erreur_execution_page' => 'fel d&aring; sidan genererades', # MODIF
'zbug_erreur_filtre' => 'Fel - odefinierat filter: <b>"@filtre@"</b>', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} anv&auml;nds exklusivt f&ouml;r l&auml;nkarna (FORUMS) eller (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Fel i Mallen',
'zbug_hors_compilation' => 'Okompilerad',
'zbug_info_erreur_squelette' => '&#1615;Fel i sajten',
'zbug_inversion_ordre_inexistant' => 'invertering av en ordningsf&ouml;ljd som inte finns', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION tagg utan {pagination} kriteriet, eller anv&auml;nd i en rekursiv slinga', # MODIF
'zbug_parametres_inclus_incorrects' => 'Felaktiga parametrar f&ouml;r inkludering', # MODIF
'zbug_profile' => 'Genereringstid: @time@',
'zbug_resultat' => 'resultat',
'zbug_serveur_indefini' => 'ingen SQL-server &auml;r definierad', # MODIF
'zbug_statistiques' => 'statistik f&ouml;r SQL-satser ordnade efter tids&aring;tg&aring;ng.',
'zbug_table_inconnue' => 'SQL-tabellen &laquo;@table@&raquo; ok&auml;nd',
'zxml_connus_attributs' => 'k&auml;nda attribut',
'zxml_de' => 'fr&aring;n',
'zxml_inconnu_attribut' => 'Ok&auml;nt attribut',
'zxml_inconnu_balise' => 'Ok&auml;nd tagg',
'zxml_inconnu_entite' => 'ok&auml;nd entitet',
'zxml_inconnu_id' => 'ok&auml;nt ID',
'zxml_mais_de' => 'utan fr&aring;n',
'zxml_non_conforme' => 'f&ouml;ljer inte principen',
'zxml_non_fils' => '&auml;rver inte fr&aring;n',
'zxml_nonvide_balise' => 'tagg ej tom',
'zxml_obligatoire_attribut' => 'obligatoriskt attribut saknas i ',
'zxml_succession_fils_incorrecte' => 'felaktigt arv',
'zxml_survoler' => 'f&ouml;r att se de r&auml;tta, h&aring;ll muspekaren ovenf&ouml;r',
'zxml_valeur_attribut' => 'v&auml;rde f&ouml;r attribut',
'zxml_vide_balise' => 'tom tagg',
'zxml_vu' => 'tidigare sedd'
);

?>
